==> muse_0.5.2.orig.tar.gz: muse-0.5.2/widgets/comboQuant.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//    $Id: comboQuant.cpp,v 1.1 2002/01/30 14:54:03 muse Exp $
//  (C) Copyright 2001 Werner Schweer (ws@seh.de)
//=========================================================

#include <qlistbox.h>
#include "comboQuant.h"

static int quantTable[] = {
      1, 16, 32,  64, 128, 256,  512, 1024,
      1, 24, 48,  96, 192, 384,  768, 1536,
      1, 36, 72, 144, 288, 576, 1152, 2304
      };

static const char* quantStrings[] = {
      "Aus", "64T", "32T", "16T", "8T", "4T", "2T", "1T",
      "Aus", "64",  "32",  "16",  "8",  "4",  "2",  "1",
      "Aus", "64.", "32.", "16.", "8.", "4.", "2.", "1."
      };

//---------------------------------------------------------
//   ComboQuant
//---------------------------------------------------------

ComboQuant::ComboQuant(QWidget* parent = 0, const char* name = 0)
   : QComboBox(parent, name)
      {
      QListBox* qlist = new QListBox(this);
      qlist->setMinimumWidth(95);
      setListBox(qlist);
      qlist->setColumnMode(3);
      for (int i = 0; i < 24; i++)
            qlist->insertItem(quantStrings[i], i);
      connect(this, SIGNAL(activated(int)), SLOT(activated(int)));
      }

//---------------------------------------------------------
//   activated
//---------------------------------------------------------

void ComboQuant::activated(int index)
      {
      emit valueChanged(quantTable[index]);
      }

//---------------------------------------------------------
//   setQuant
//---------------------------------------------------------

void ComboQuant::setValue(int val)
      {
      for (int i = 0; i < 24; i++) {
            if (val == quantTable[i]) {
                  setCurrentItem(i);
                  return;
                  }
            }
      }

==> muse_0.6.3.orig.tar.gz: muse-0.6.3/widgets/comboQuant.cpp <==
//=========================================================
//  MusE
//  Linux Music Editor
//    $Id: comboQuant.cpp,v 1.1.1.1 2003/10/29 10:06:29 wschweer Exp $
//  (C) Copyright 2001 Werner Schweer (ws@seh.de)
//=========================================================

#include <qlistbox.h>
#include "comboQuant.h"

static int quantTable[] = {
      1, 16, 32,  64, 128, 256,  512, 1024,
      1, 24, 48,  96, 192, 384,  768, 1536,
      1, 36, 72, 144, 288, 576, 1152, 2304
      };

static const char* quantStrings[] = {
      QT_TR_NOOP("Off"), "64T", "32T", "16T", "8T", "4T", "2T", "1T",
      QT_TR_NOOP("Off"), "64",  "32",  "16",  "8",  "4",  "2",  "1",
      QT_TR_NOOP("Off"), "64.", "32.", "16.", "8.", "4.", "2.", "1."
      };

//---------------------------------------------------------
//   ComboQuant
//---------------------------------------------------------

ComboQuant::ComboQuant(QWidget* parent, const char* name)
   : QComboBox(parent, name)
      {
      QListBox* qlist = new QListBox(this);
      qlist->setMinimumWidth(95);
      setListBox(qlist);
      qlist->setColumnMode(3);
      for (int i = 0; i < 24; i++)
            qlist->insertItem(tr(quantStrings[i]), i);
      connect(this, SIGNAL(activated(int)), SLOT(activated(int)));
      }

//---------------------------------------------------------
//   activated
//---------------------------------------------------------

void ComboQuant::activated(int index)
      {
      emit valueChanged(quantTable[index]);
      }

//---------------------------------------------------------
//   setQuant
//---------------------------------------------------------

void ComboQuant::setValue(int val)
      {
      for (int i = 0; i < 24; i++) {
            if (val == quantTable[i]) {
                  setCurrentItem(i);
                  return;
                  }
            }
      }
